@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 
+from . import config
+
+from . import date_use
 from . import latex_use
 from . import log_test_use
 from . import os_use
