@@ -13,9 +13,8 @@ langage for typing scientific documents.
 
 import os
 import subprocess
-import collections
 
-from mistool import os_use
+from mistool import config, os_use
 
 
 # ------------------------- #
@@ -24,9 +23,9 @@ from mistool import os_use
 
 class LaTeXUseError(ValueError):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Base class for errors in the ``latex_use`` module of the package ``mistool``.
     """
@@ -38,9 +37,9 @@ def __raiseSomeError(
     action
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method simply eases the raising of some specific errors.
     """
@@ -68,38 +67,17 @@ This method simply eases the raising of some specific errors.
 # -- FORMATTING -- #
 # ---------------- #
 
-# --- START-ESCAPE ---#
-
-# The two following variables were automatically built by one Python script.
-
-# Sources :
-#    * The page 7 in "The Comprehensive LATEX Symbol List" of Scott Pakin.
-#    * http://www.grappa.univ-lille3.fr/FAQ-LaTeX/21.26.html
-
-CHAR_TO_ESCAPE = {
-    'text': "{}_$&%#",
-    'math': "{}_$&%#"
-}
-
-CHAR_TO_LATEXIFY = {
-    'text': {
-        '\\': "\\textbackslash{}"
-    },
-    'math': {
-        '\\': "\\backslash{}"
-    }
-}
-
-# --- END-ESCAPE ---#
+CHAR_TO_ESCAPE   = config.latex.CHAR_TO_ESCAPE
+CHAR_TO_LATEXIFY = config.latex.CHAR_TO_LATEXIFY
 
 def escape(
     text,
     mode = "text"
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 In LaTeX language, somme character has one meaning. The purpose of this function
 is to escape all this special charcaters so as to see them in the output
@@ -112,9 +90,9 @@ For example, ``escape("\OH/ & ...")`` is equal to ``"\textbackslash{}OH/ \&
 indicated by using two different LaTeX commands.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -175,15 +153,16 @@ info::
 
 class Build:
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This class defines methods related to the compilation of LaTeX documents.
 
--------------
+
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This class uses the following variables.
 
@@ -248,9 +227,9 @@ This class uses the following variables.
         repeat
     ):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method launches the compilation in verbose mode or not.
         """
@@ -277,9 +256,9 @@ This method launches the compilation in verbose mode or not.
         repeat = None
     ):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method calls LaTeX so as to build the PDF output.
         """
@@ -302,91 +281,8 @@ This method calls LaTeX so as to build the PDF output.
 # -- CLEANING -- #
 # -------------- #
 
-# --- START-CLEAN ---#
-
-# The two following variables were automatically built by one Python script.
-
-CLASSIFIED_TEMP_EXT = collections.OrderedDict([
-    ('debug', ['blg', 'ilg', 'log', 'glg']),
-    ('html', ['4ct', '4tc', 'idv', 'lg', 'tmp', 'xref']),
-    ('slide', ['nav', 'snm', 'vrb']),
-    ('editor', ['synctex.gz', 'synctex.gz(busy)']),
-    ('float', ['fff', 'ttt']),
-    ('list', ['lof', 'lol', 'lot', 'bcl']),
-    ('toc', ['toc', 'maf', 'mlf', 'mlt', 'mtc', 'plf', 'plt', 'ptc']),
-    ('ref', ['aux', 'brf', 'out', 'glo', 'ist', 'gls', 'idx', 'ind']),
-    ('biblio', ['bbl', 'run.xml']),
-    ('theorem', ['thm']),
-    ('eledmac', ['¨number']),
-    ('eledpar', ['R¨number'])
-])
-
-ALL_EXT_TO_CLEAN = [
-# debug
-#
-# ``log`` is produced by latex compilations, ``ilg`` and ``glg`` by
-# makeindex compilations, where ``glg`` is related to the package glossary.
-# ``blg`` is produced by bibtex compilations.
-    'blg', 'ilg', 'log', 'glg',
-# html
-#
-# This extensions are produced by the package ``tex4ht``.
-    '4ct', '4tc', 'idv', 'lg', 'tmp', 'xref',
-# slide
-#
-#
-    'nav', 'snm', 'vrb',
-# editor
-#
-# ``synctex.gz`` is produced by some editors to do synchronization between
-# the LaTeX source file and its PDF output.
-    'synctex.gz', 'synctex.gz(busy)',
-# float
-#
-#
-    'fff', 'ttt',
-# list
-#
-# ``bcl`` is produced by the package ``bclogo`` : this gives the list of
-# the logos.
-#
-# ``f`` is for Figure, ``l`` for Listing (cf. the package ``listings``),
-# and ``t`` for Table.
-    'lof', 'lol', 'lot', 'bcl',
-# toc
-#
-# The package ``minitoc`` produces all this extensions excepted ``toc``.
-    'toc', 'maf', 'mlf', 'mlt', 'mtc', 'plf', 'plt', 'ptc',
-# ref
-#
-# ``out`` is produced by the package ``hyperref`` with the option
-# ``bookmarks``, and ``brf`` with the option ``backref``.
-#
-# The package `` glossary`` produces ``glo`` and ``gls``, and also ``ist``
-# if an additional makeindex compilation is launched.
-#
-# ``idx`` and ``ind`` are produced by makeindex compilations.
-    'aux', 'brf', 'out', 'glo', 'ist', 'gls', 'idx', 'ind',
-# biblio
-#
-# ``bbl`` is produces by bibtex compilations, and ``run.xml`` by biber
-# compilations.
-    'bbl', 'run.xml',
-# theorem
-#
-#
-    'thm',
-# eledmac
-#
-#
-    '¨number',
-# eledpar
-#
-#
-    'R¨number'
-]
-
-# --- END-CLEAN ---#
+CLASSIFIED_TEMP_EXT = config.latex.CLASSIFIED_TEMP_EXT
+ALL_EXT_TO_CLEAN    = config.latex.ALL_EXT_TO_CLEAN
 
 def clean(
     main,
@@ -396,16 +292,16 @@ def clean(
     verbose = False
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function removes extra files build during a LaTeX compilation.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -459,14 +355,14 @@ This function uses the following variables.
 
 # One directory
     elif os_use.isDir(main):
-        thePathsNoExt = []
-
-        for oneFile in os_use.nextFile(
-            main  = main,
-            ext   = {'keep': ["tex"]},
-            depth = depth
-        ):
-            thePathsNoExt.append(oneFile[:-4])
+        thePathsNoExt = [
+            oneFile[:-4]
+            for oneFile in os_use.nextFile(
+                main  = main,
+                ext   = {'keep': ["tex"]},
+                depth = depth
+            )
+        ]
 
 # Nothing existing
     else:
@@ -478,7 +374,7 @@ This function uses the following variables.
             print('---> "{0}.tex"'.format(pathNoExt))
 
         for oneExt in [x for x in discard if x not in keep]:
-            if '¨number' in oneExt:
+            if '¨' in oneExt:
                 print("TODO  --->  ", oneExt)
                 ...
 
@@ -497,9 +393,9 @@ This function uses the following variables.
 
 def mikeTexLocalDirectory():
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 You can redefine this function to choose another path than
 path::``C:/texmf-local`` for the directory where we'll put special LaTeX
@@ -507,7 +403,7 @@ packages.
 
 
 warning::
-    Customize this function if you know what you are doing !
+    Customize this function only if you know what you are doing !
     """
     return 'C:/texmf-local'
 
@@ -515,9 +411,9 @@ def __localDirOfTexLive(
     osName = None
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function returns the path of the TeX Live directory where we'll put special
 LaTeX packages.
@@ -547,9 +443,9 @@ LaTeX packages.
 
 def about():
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 The aim of this function is to give critical informations so to use the function
 ``install`.
@@ -619,9 +515,9 @@ The key ``'localDir'`` contains the path to use to install special packages.
 
 def __issu(localLatexDir):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the script has been launched by the "Super User".
     """
@@ -643,9 +539,9 @@ This function tests if the script has been launched by the "Super User".
 
 def makeMiktexLocalDir():
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function creates one local directory and add it to the list of directories
 analysed by MiKTeX when it looks for packages.
@@ -705,9 +601,9 @@ def refresh(
     aboutLatex = None
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function refreshes the list of packages directly known by the LaTeX
 distribution. This always works in verbose mode (LaTeX is not very talkative
@@ -740,9 +636,9 @@ def install(
     clean = False
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function helps you to easily install unofficial packages to your LaTeX
 distribution.
@@ -752,9 +648,9 @@ warning::
     This function can only be called by one script launched by the super user.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
