@@ -30,9 +30,9 @@ from mistool import os_use, python_use, string_use
 
 class LogTestUseError(ValueError):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Base class for errors in the ``log_test_use`` module of the package ``mistool``.
     """
@@ -40,9 +40,9 @@ Base class for errors in the ``log_test_use`` module of the package ``mistool``.
 
 def __unexpectedError(text):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This is for errors not expected during the tests.
     """
@@ -72,9 +72,9 @@ def what(
     isMethod = False
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function transforms some text like ``Abreviations__NewAdding_Good`` into
 ``Abreviations ---> New Adding - Good`` where the replacements are defined in
@@ -95,15 +95,16 @@ removed. This is useful because the module ``unittest`` only calls the methods
 with a name started by ``test``.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses two arguments.
 
     1) ``text`` is a text of something that is tested.
 
-    2) ``isMethod`` is an optional boolean variable. By default, ``isMethod = False``.
+    2) ``isMethod`` is an optional boolean variable. By default, ``isMethod =
+    False``.
     """
     if isMethod:
         if not text.startswith('test'):
@@ -122,9 +123,9 @@ This function uses two arguments.
 
 def __isDict(obj):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function returns ``True`` if the argument ``obj`` is a dictionnary (ordered
 or not). If this is not the case, the function returns ``False``.
@@ -137,9 +138,9 @@ def diffDict(
     recursive = False
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function analyses if the two dictionaries ``dict_1`` and ``dict_2`` are
 equal. If it is the case, an empty string is returned. In the other case, a
@@ -154,9 +155,9 @@ dictionaries, then the function ``diffDict`` will be called recursively for a
 finer message indicating the differences.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -201,9 +202,9 @@ This function uses the following variables.
 
 def logPrint(text):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is used to display messages. By default, ``logPrint`` is simply
 equal to ``print``.
@@ -213,9 +214,9 @@ You can redefine this function to change the way the messages are "displayed"
 so as to build log files for example.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function has only one variable ``text`` which is a string.
     """
@@ -228,16 +229,16 @@ def info(
     end   = "..."
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is usefull for displaying very short infos in one line.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function has four arguments.
 
@@ -253,16 +254,17 @@ This function has four arguments.
         '{0}{1} "{2}"{3}'.format(start, kind, text, end)
     )
 
+FRAME_PROBLEM = string_use.FRAME_FORMATS['unittest_problem']
 
 def problem(
     text,
-    format = string_use.UNITTEST_PROBLEM_FRAME,
+    format = FRAME_PROBLEM,
     center = True
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is useful for displaying problems met during one test.
 
@@ -271,9 +273,9 @@ center)`` (take a look at the documentation of the module ``string_use`` if
 you want to use your own format of frame).
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -281,7 +283,7 @@ This function uses the following variables.
 
     2) ``format`` is the format of the frame following the specifications of the
     function ``string_use.frame``. This an optional argument. By default,
-    ``format = string_use.UNITTEST_PROBLEM_FRAME``.
+    ``format = string_use.FRAME_FORMATS['unittest_problem']``.
 
     3) ``center`` is a boolean optional variable which aks to center or not the
     text. By default, ``center = True``.
@@ -299,6 +301,8 @@ This function uses the following variables.
 # -- TEST SUITE -- #
 # ---------------- #
 
+FRAME_LAUNCH_TEST = string_use.FRAME_FORMATS['python_basic']
+
 def launchTestSuite(
     dir,
     depth     = 0,
@@ -307,9 +311,9 @@ def launchTestSuite(
     sort      = lambda x: x
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function simplifies a lot the launching of unit tests made via the module
 ``unittest``.
@@ -318,9 +322,9 @@ This function simplifies a lot the launching of unit tests made via the module
 See the meaning of the arguments so as to know how to use this function.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -392,7 +396,7 @@ This function uses the following variables.
             logPrint(
                 "\n" + string_use.frame(
                     text   = message,
-                    format = string_use.PYTHON_FRAME
+                    format = FRAME_LAUNCH_TEST
                 ) + "\n"
             )
 
