@@ -3,7 +3,7 @@
 """
 Directory : mistool
 Name      : os_use
-Version   : 2013.09
+Version   : 2013.10
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -23,9 +23,9 @@ import subprocess
 
 class OsUseError(ValueError):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Base class for errors in the ``os_use`` module of the package ``mistool``.
     """
@@ -38,9 +38,9 @@ Base class for errors in the ``os_use`` module of the package ``mistool``.
 
 def isFile(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function simply tests if the path ``path`` points to an existing file.
     """
@@ -48,9 +48,9 @@ This function simply tests if the path ``path`` points to an existing file.
 
 def isDir(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function simply tests if the path ``path`` points to an existing directory.
     """
@@ -61,9 +61,9 @@ def hasExtIn(
     listOfExt
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the path ``path`` finishes by one of the extensions given
 in the list of extensions ``listOfExt``.
@@ -84,9 +84,9 @@ SEP = os.sep
 
 def name(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function extracts from the path ``path`` the name of the file with its
 extension or simply the name of one directory.
@@ -97,9 +97,9 @@ extension or simply the name of one directory.
 
 def fileName(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function extracts from the path ``path`` the name of the file without its
 extension.
@@ -108,9 +108,9 @@ extension.
 
 def ext(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function extracts from the path ``path`` the extension of the file.
     """
@@ -118,9 +118,9 @@ This function extracts from the path ``path`` the extension of the file.
 
 def pathNoExt(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function removes from the path ``path`` the extension of the file.
     """
@@ -135,9 +135,9 @@ This function removes from the path ``path`` the extension of the file.
 
 def parentDir(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function returns the path of the directory that contains the file or the
 directory corresponding to the path ``path``.
@@ -149,9 +149,9 @@ def relativePath(
     sub,
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Suppose that we have the following paths where ``main`` is the path of the main
 directory and ``sub`` the one of a sub directory or a file contained in the main
@@ -201,9 +201,9 @@ def relativeDepth(
     sub
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Suppose that we have the following paths where ``main`` is the path of the main
 directory and ``sub`` the one of a sub directory or a file contained in the main
@@ -235,31 +235,29 @@ directory. Here are some examples.
         sub         = sub
     ).count(SEP) - 1
 
-def commonPath(
-    listPath
-):
+def commonPath(paths):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function returns the smaller directory that contains the objects having the
-paths given in the list ``listPath``.
+paths given in the list ``paths``.
     """
-    if len(listPath) < 2:
+    if len(paths) < 2:
         raise OsUseError(
             "You must give at least two paths."
         )
 
-    if len(listPath) == 2:
+    if len(paths) == 2:
         answer = []
 
-        path1 = listPath[0].split(SEP)
-        path2 = listPath[1].split(SEP)
+        pieces_1 = paths[0].split(SEP)
+        pieces_2 = paths[1].split(SEP)
 
-        for i in range(min(len(path1), len(path2))):
-            if path1[i] == path2[i]:
-                answer.append(path1[i])
+        for i in range(min(len(pieces_1), len(pieces_2))):
+            if pieces_1[i] == pieces_2[i]:
+                answer.append(pieces_1[i])
             else:
                 break
 
@@ -267,7 +265,7 @@ paths given in the list ``listPath``.
 
     else:
         return commonPath([
-            commonPath(listPath[:-1]), listPath[-1]
+            commonPath(paths[:-1]), paths[-1]
         ])
 
 
@@ -277,9 +275,9 @@ paths given in the list ``listPath``.
 
 def watch(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tries to open one directory, or one file. Indeed, files are opened
 within their associated applications, if this last ones exist.
@@ -331,9 +329,9 @@ def readTextFile(
     encoding = "utf-8"
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function returns the text like content of one file given by its path.
 
@@ -355,9 +353,9 @@ same as the ones for the standard ¨python function ``open``.
 
 def makeDir(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function build the directory with the given path ``path``. If one parent
 directory must be build, the function will do the job.
@@ -371,15 +369,16 @@ def makeTextFile(
     encoding = 'utf-8'
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
-This function build the file with the given path ``path`` and the text like content ``text``.
+This function build the file with the given path ``path`` and the text like
+content ``text``.
 
-You can indicate the encoding of the file with the optional argument
-``encoding`` whose dfault value is ``"utf-8"``. The available encodings are the
-same as the ones for the standard ¨python function ``open``.
+You can indicate the encoding of the file with the optional argument ``encoding``
+whose dfault value is ``"utf-8"``. The available encodings are the same as the
+ones for the standard ¨python function ``open``.
     """
     makeDir(parentDir(path))
 
@@ -395,9 +394,9 @@ def move(
     destination
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function moves the file or the directory from the path ``source`` to the
 path ``destination``. If the source and the destination have the same parent
@@ -417,9 +416,9 @@ def copy(
     destination
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function copy the file having the path ``source`` to the destination path
 ``destination``.
@@ -444,9 +443,9 @@ This function copy the file having the path ``source`` to the destination path
 
 def destroy(path):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function removes the directory or the file given by its path ``path``.
     """
@@ -462,16 +461,16 @@ def clean(
     depth = 0
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function removes files in one directory regarding to their extension.
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This functions uses the following variables.
 
@@ -502,9 +501,9 @@ def __isSubDepthGood(
     depth
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This small function is used by ``nextFile`` so as to know if one directory must
 be inspected or not.
@@ -534,9 +533,9 @@ def __isFileGood(
     prefix
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This small function is used by ``nextFile`` so as to know if the file found
 matches the search criteria about extensions and prefixes.
@@ -570,9 +569,9 @@ matches the search criteria about extensions and prefixes.
 
 def __toKeepToDiscard(extOrPref):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This small function is used by ``nextFile`` so as to produce one normalized
 dictionary of the variables ``ext`` and ``prefix``.
@@ -607,9 +606,9 @@ def nextFile(
     keepDir = None
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is an iterator that sends path of files in a directory with the
 possibility to use some criteria of research.
@@ -719,9 +718,9 @@ terminal::
     /Users/mistool/debug/debug_latex_use/latexTestBuilder.py
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -837,9 +836,9 @@ This function uses the following variables.
 
 def listFile(*args, **kwargs):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is similar to the function ``nextFile``, and it has the same
 variables that the ones of ``nextFile``, but instead of sending infos about the
@@ -864,9 +863,9 @@ def nextDir(
     depth = 0
 ):
     """"
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is an iterator that sends path of directories contained in a
 directory.
@@ -923,9 +922,9 @@ terminal::
     /Users/mistool/toUse/latex
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -975,9 +974,9 @@ This function uses the following variables.
 
 def listDir(*args, **kwargs):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is similar to the function ``nextDir``, and it has the same
 variables that the ones of ``nextDir``, but instead of sending infos about the
@@ -994,9 +993,9 @@ list returned by ``listDir``.
 
 class DirView:
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This class displays the tree structure of one directory with the possibility to
 keep only some relevant informations like in the following example.
@@ -1042,9 +1041,9 @@ python::
     print(dirView.ascii)
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This class uses the following variables.
 
@@ -1101,9 +1100,9 @@ This class uses the following variables.
 
     def build(self):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method builds one list of dictionaries of the following kind.
 
@@ -1174,9 +1173,9 @@ python::
 
     def __otherFiles(self, onePath):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method displays text indicated that other files are in the directory.
         """
@@ -1208,11 +1207,11 @@ This method displays text indicated that other files are in the directory.
     @property
     def ascii(self):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
-This method returns a simple ASCCI tree view of the tree structure.
+This property like method returns a simple ASCCI tree view of the tree structure.
         """
         if 'ascii' not in self.format:
             text = []
@@ -1247,9 +1246,9 @@ This method returns a simple ASCCI tree view of the tree structure.
 
 def pathEnv():
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function simply returns the variable ``PATH`` that contains paths of some
 executables known by your OS.
@@ -1258,9 +1257,9 @@ executables known by your OS.
 
 def system():
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 The purpose of this function is to give the name, in lower case, of the OS used.
 Possible names can be "windows", "mac", "linux" and also "java".
