@@ -6,7 +6,7 @@
 """
 Directory : mistool
 Name      : regex_use
-Version   : 2013.05
+Version   : 2013.10
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -22,9 +22,9 @@ import re
 
 class RegexUseError(ValueError):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Base class for errors in the ``regex_use`` module of the package ``mistool``.
     """
@@ -69,9 +69,9 @@ def isVarName(
     kind = "standard"
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` is one legal name for variable for
 different contexts given by the value of ``kind``. This argument corresponds to
@@ -88,9 +88,9 @@ python::
     }
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This function uses the following variables.
 
@@ -146,15 +146,42 @@ PATTERN_ROMAN_NUMERAL = re.compile(
     re.VERBOSE
 )
 
-def isUpperRoman(text):
+def isRoman(
+    text,
+    case = "upper"
+):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` corresponds to one roman number using
-upper case letters. The pattern used is the following one coming from the book
-"Dive into Python".
+one case given by ``case``, the default value being upper case.
+
+
+:::::::::::::
+The arguments
+:::::::::::::
+
+This function uses three variables.
+
+    1) ``text`` is the string to test.
+
+    2) ``case`` is a string that can be equal to one of the three following
+    values.
+
+        a) ``"upper"`` is for upper roman number. This is the default value.
+
+        b) ``"lower"`` is for lower roman number.
+
+        c) ``"mix"`` says that we do not care of the case.
+
+
+::::::::::::::
+Technical note
+::::::::::::::
+
+The pattern used is the following one coming from the book "Dive into Python".
 
 python::
     PATTERN_ROMAN_NUMERAL = re.compile(
@@ -176,22 +203,21 @@ python::
         re.VERBOSE
     )
     """
+    if case == "mix":
+        text = text.upper()
+
+    elif case == "upper":
+        if not text.isupper():
+            return False
+
+    elif case == "lower":
+        if not text.islower():
+            return False
+
+        text = text.upper()
+
     return bool(PATTERN_ROMAN_NUMERAL.search(text))
 
-def isLowerRoman(text):
-    """
------------------
-Small description
------------------
-
-This function tests if the string ``text`` corresponds to one roman number using
-lower case letters. All the hard job is done by the function ``isUpperRoman``.
-    """
-    if text != text.lower():
-        return False
-
-    return isUpperRoman(text.upper())
-
 
 # ------------------------- #
 # -- MATHEMATICAL NUMBER -- #
@@ -201,9 +227,9 @@ PATTERN_NATURAL = re.compile("^(\d)+$")
 
 def isNatural(text):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` corresponds to one natural number.
     """
@@ -211,9 +237,9 @@ This function tests if the string ``text`` corresponds to one natural number.
 
 def isInteger(text):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` corresponds to one integer.
     """
@@ -228,9 +254,9 @@ def __isTwoParts(
     tests
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function is used by either ``isRational``, ``isDecimal``, or ``isFloat``.
 It splits the string ``text`` regarding to ``sep``.
@@ -252,9 +278,9 @@ eventually the second part by calling the function ``test[1]``.
 
 def isRational(text):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` corresponds to one rational number.
     """
@@ -269,9 +295,9 @@ def isDecimal(
     sep = "."
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` corresponds to one decimal number
 using ``sep`` as decimal separator. By default, ``sep = "."``.
@@ -288,9 +314,9 @@ def isFloat(
     expo = "E"
 ):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests if the string ``text`` corresponds to one float number like
 ``-123.45E+45`` where the function uses the optional arguments ``sep = "."`` for
